@@ -22,33 +22,37 @@
 #' @examples
 #' has_rtools()
 has_rtools <- function(debug = FALSE) {
-  if (!debug && rtools_path_is_set())
+  if (!debug && rtools_path_is_set()) {
     return(!identical(rtools_path(), ""))
+  }
 
-  if (!is_windows())
+  if (!is_windows()) {
     return(FALSE)
+  }
 
   # R 4.2.x or later and ucrt?
   ucrt <- is_ucrt()
   if (ucrt) {
     rtools42_home <- Sys.getenv("RTOOLS42_HOME", "C:\\rtools42")
-    if(file.exists(file.path(rtools42_home, 'usr', 'bin'))){
-      if (debug)
+    if (file.exists(file.path(rtools42_home, "usr", "bin"))) {
+      if (debug) {
         cat("Found in Rtools 4.2 installation folder\n")
-      rtools_path_set(rtools(rtools42_home, '4.2'))
+      }
+      rtools_path_set(rtools(rtools42_home, "4.2"))
       return(TRUE)
     }
   }
 
   # In R 4.0 we can use RTOOLS40_HOME, recent versions of Rtools40 work fine
   # with ucrt as well, currently.
-  if(is_R4()) {
-    rtools40_home <- Sys.getenv('RTOOLS40_HOME', 'C:\\rtools40')
+  if (is_R4()) {
+    rtools40_home <- Sys.getenv("RTOOLS40_HOME", "C:\\rtools40")
     fld <- if (ucrt) "ucrt64" else "usr"
-    if (file.exists(file.path(rtools40_home, fld, 'bin'))){
-      if (debug)
+    if (file.exists(file.path(rtools40_home, fld, "bin"))) {
+      if (debug) {
         cat("Found in Rtools 4.0 installation folder\n")
-      rtools_path_set(rtools(rtools40_home, '4.0'))
+      }
+      rtools_path_set(rtools(rtools40_home, "4.0"))
       return(TRUE)
     }
   }
@@ -57,8 +61,9 @@ has_rtools <- function(debug = FALSE) {
   # This does not work if 'make' is not yet on the path
   from_config <- scan_config_for_rtools(debug)
   if (is_compatible(from_config)) {
-    if (debug)
+    if (debug) {
       cat("Found compatible gcc from R CMD config CC\n")
+    }
     rtools_path_set(from_config)
     return(TRUE)
   }
@@ -66,8 +71,9 @@ has_rtools <- function(debug = FALSE) {
   # Next, try the path ------------------------------------------------
   from_path <- scan_path_for_rtools(debug)
   if (is_compatible(from_path)) {
-    if (debug)
+    if (debug) {
       cat("Found compatible gcc on path\n")
+    }
     rtools_path_set(from_path)
     return(TRUE)
   }
@@ -76,16 +82,19 @@ has_rtools <- function(debug = FALSE) {
     # Installed
     if (is.null(from_path$version)) {
       # but not from rtools
-      if (debug)
+      if (debug) {
         cat("gcc and ls on path, assuming set up is correct\n")
+      }
       return(TRUE)
     } else {
       # Installed, but not compatible
       needed <- rtools_needed()
-      message("WARNING: Rtools ", from_path$version, " found on the path",
+      message(
+        "WARNING: Rtools ", from_path$version, " found on the path",
         " at ", from_path$path, " is not compatible with R ", getRversion(), ".\n\n",
         "Please download and install ", needed, " from ", rtools_url(needed),
-        ", remove the incompatible version from your PATH.")
+        ", remove the incompatible version from your PATH."
+      )
       return(invisible(FALSE))
     }
   }
@@ -96,9 +105,11 @@ has_rtools <- function(debug = FALSE) {
   if (length(registry_candidates) == 0) {
     # Not on path or in registry, so not installled
     needed <- rtools_needed()
-    message("WARNING: Rtools is required to build R packages, but is not ",
+    message(
+      "WARNING: Rtools is required to build R packages, but is not ",
       "currently installed.\n\n",
-      "Please download and install ", needed, " from ", rtools_url(needed), ".")
+      "Please download and install ", needed, " from ", rtools_url(needed), "."
+    )
     return(invisible(FALSE))
   }
 
@@ -107,37 +118,43 @@ has_rtools <- function(debug = FALSE) {
     # In registry, but not compatible.
     versions <- vapply(registry_candidates, function(x) x$version, character(1))
     needed <- rtools_needed()
-    message("WARNING: Rtools is required to build R packages, but no version ",
+    message(
+      "WARNING: Rtools is required to build R packages, but no version ",
       "of Rtools compatible with R ", getRversion(), " was found. ",
       "(Only the following incompatible version(s) of Rtools were found: ",
       paste(versions, collapse = ", "), ")\n\n",
-      "Please download and install ", needed, " from ", rtools_url(needed), ".")
+      "Please download and install ", needed, " from ", rtools_url(needed), "."
+    )
     return(invisible(FALSE))
   }
 
   # On Rtools 3.x do an extra check if the installed version is accurate.
   # With rtools40 this is no longer needed (it doens't have a Version.txt)
-  if(isTRUE(from_registry$version < '4')){
+  if (isTRUE(from_registry$version < "4")) {
     installed_ver <- installed_version(from_registry$path, debug = debug)
     if (is.null(installed_ver)) {
       # Previously installed version now deleted
       needed <- rtools_needed()
-      message("WARNING: Rtools is required to build R packages, but the ",
+      message(
+        "WARNING: Rtools is required to build R packages, but the ",
         "version of Rtools previously installed in ", from_registry$path,
         " has been deleted.\n\n",
-        "Please download and install ", needed, " from ", rtools_url(needed), ".")
+        "Please download and install ", needed, " from ", rtools_url(needed), "."
+      )
       return(invisible(FALSE))
     }
 
     if (installed_ver != from_registry$version) {
       # Installed version doesn't match registry version
       needed <- rtools_needed()
-      message("WARNING: Rtools is required to build R packages, but no version ",
+      message(
+        "WARNING: Rtools is required to build R packages, but no version ",
         "of Rtools compatible with R ", getRversion(), " was found. ",
         "Rtools ", from_registry$version, " was previously installed in ",
         from_registry$path, " but now that directory contains Rtools ",
         installed_ver, ".\n\n",
-        "Please download and install ", needed, " from ", rtools_url(needed), ".")
+        "Please download and install ", needed, " from ", rtools_url(needed), "."
+      )
       return(invisible(FALSE))
     }
   }
@@ -164,14 +181,17 @@ setup_rtools <- has_rtools
 #' @export
 #' @rdname has_rtools
 check_rtools <- function(debug = FALSE) {
-  if (is_windows() && !has_rtools(debug = debug))
+  if (is_windows() && !has_rtools(debug = debug)) {
     stop("Rtools is not installed.", call. = FALSE)
+  }
 
   TRUE
 }
 
 installed_version <- function(path, debug) {
-  if (!file.exists(file.path(path, "Rtools.txt"))) return(NULL)
+  if (!file.exists(file.path(path, "Rtools.txt"))) {
+    return(NULL)
+  }
 
   # Find the version path
   version_path <- file.path(path, "VERSION.txt")
@@ -179,30 +199,42 @@ installed_version <- function(path, debug) {
     cat("VERSION.txt\n")
     cat(readLines(version_path), "\n")
   }
-  if (!file.exists(version_path)) return(NULL)
+  if (!file.exists(version_path)) {
+    return(NULL)
+  }
 
   # Rtools is in the path -- now crack the VERSION file
   contents <- NULL
   try(contents <- readLines(version_path), silent = TRUE)
-  if (is.null(contents)) return(NULL)
+  if (is.null(contents)) {
+    return(NULL)
+  }
 
   # Extract the version
   contents <- gsub("^\\s+|\\s+$", "", contents)
   version_re <- "Rtools version (\\d\\.\\d+)\\.[0-9.]+$"
 
-  if (!grepl(version_re, contents)) return(NULL)
+  if (!grepl(version_re, contents)) {
+    return(NULL)
+  }
 
   m <- regexec(version_re, contents)
   regmatches(contents, m)[[1]][2]
 }
 
 is_compatible <- function(rtools) {
-  if (is.null(rtools)) return(FALSE)
-  if (is.null(rtools$version)) return(FALSE)
+  if (is.null(rtools)) {
+    return(FALSE)
+  }
+  if (is.null(rtools$version)) {
+    return(FALSE)
+  }
 
   stopifnot(is.rtools(rtools))
   info <- version_info[[rtools$version]]
-  if (is.null(info)) return(FALSE)
+  if (is.null(info)) {
+    return(FALSE)
+  }
 
   r_version <- getRversion()
   r_version >= info$version_min && r_version <= info$version_max
@@ -225,8 +257,9 @@ rtools_needed <- function(r_version = getRversion()) {
     version <- names(vi)[i]
     info <- vi[[i]]
     ok <- r_version >= info$version_min && r_version <= info$version_max
-    if (ok)
+    if (ok) {
       return(paste("Rtools", version))
+    }
   }
   "the appropriate version of Rtools"
 }
