@@ -12,14 +12,12 @@
 #' @examples
 #' flags <- names(compiler_flags(TRUE))
 #' with_debug(Sys.getenv(flags))
-#'
 #' \dontrun{
 #' install("mypkg")
 #' with_debug(install("mypkg"))
 #' }
 with_debug <- function(code, CFLAGS = NULL, CXXFLAGS = NULL,
                        FFLAGS = NULL, FCFLAGS = NULL, debug = TRUE) {
-
   defaults <- compiler_flags(debug = debug)
   flags <- c(
     CFLAGS = CFLAGS, CXXFLAGS = CXXFLAGS,
@@ -68,3 +66,17 @@ without_cache <- function(code) {
 
   code
 }
+
+
+#' @export
+#' @rdname without_compiler
+without_latex <- function(code) {
+  withr::with_options(list(PKGBUILD_TEST_FIXTURE_HAS_LATEX = FALSE), code)
+}
+
+
+#' @export
+#' @rdname without_compiler
+with_latex <- function(code) {
+  withr::with_options(list(PKGBUILD_TEST_FIXTURE_HAS_LATEX = TRUE), code)
+}
